@@ -4,6 +4,7 @@ from typing import Any
 
 from linkplay.consts import (
     INPUT_MODE_MAP,
+    LOGGER,
     PLAY_MODE_SEND_MAP,
     ChannelType,
     DeviceAttribute,
@@ -130,6 +131,11 @@ class LinkPlayPlayer:
         await self.bridge.request(LinkPlayCommand.PAUSE)
         self.properties[PlayerAttribute.PLAYING_STATUS] = PlayingStatus.PAUSED
 
+    async def stop(self) -> None:
+        """Stop the current playing track and remove the selected source."""
+        await self.bridge.request(LinkPlayCommand.STOP)
+        self.properties[PlayerAttribute.PLAYING_STATUS] = PlayingStatus.STOPPED
+
     async def toggle(self) -> None:
         """Start playing if the player is currently not playing. Stops playing if it is."""
         await self.bridge.request(LinkPlayCommand.TOGGLE)
@@ -230,9 +236,12 @@ class LinkPlayPlayer:
     @property
     def play_mode(self) -> PlayingMode:
         """Returns the current playing mode of the player."""
-        return PlayingMode(
-            self.properties.get(PlayerAttribute.PLAYBACK_MODE, PlayingMode.IDLE)
-        )
+        try:
+            return PlayingMode(
+                self.properties.get(PlayerAttribute.PLAYBACK_MODE, PlayingMode.IDLE)
+            )
+        except ValueError:
+            return PlayingMode(PlayingMode.IDLE)
 
     @property
     def loop_mode(self) -> LoopMode:
@@ -250,11 +259,13 @@ class LinkPlayBridge:
     endpoint: LinkPlayEndpoint
     device: LinkPlayDevice
     player: LinkPlayPlayer
+    multiroom: LinkPlayMultiroom | None
 
     def __init__(self, *, endpoint: LinkPlayEndpoint):
         self.endpoint = endpoint
         self.device = LinkPlayDevice(self)
         self.player = LinkPlayPlayer(self)
+        self.multiroom = None
 
     def __str__(self) -> str:
         if self.device.name == "":
@@ -268,14 +279,20 @@ class LinkPlayBridge:
             "endpoint": self.endpoint.to_dict(),
             "device": self.device.to_dict(),
             "player": self.player.to_dict(),
+            "multiroom": self.multiroom.to_dict() if self.multiroom else None,
         }
 
     async def json_request(self, command: str) -> dict[str, str]:
         """Performs a GET request on the given command and returns the result as a JSON object."""
-        return await self.endpoint.json_request(command)
+        LOGGER.debug(str.format("Request {} at {}", command, self.endpoint))
+        response = await self.endpoint.json_request(command)
+        LOGGER.debug(str.format("Response {}: {}", command, response))
+        return response
 
     async def request(self, command: str) -> None:
         """Performs a GET request on the given command and verifies the result."""
+
+        LOGGER.debug(str.format("Request command at {}: {}", self.endpoint, command))
         await self.endpoint.request(command)
 
 
@@ -290,6 +307,13 @@ class LinkPlayMultiroom:
         self.leader = leader
         self.followers = []
 
+    def to_dict(self):
+        """Return the state of the LinkPlayMultiroom."""
+        return {
+            "leader": self.leader.to_dict(),
+            "followers": [follower.to_dict() for follower in self.followers],
+        }
+
     async def update_status(self, bridges: list[LinkPlayBridge]) -> None:
         """Updates the multiroom status."""
         properties: dict[Any, Any] = await self.leader.json_request(
